@@ -10,6 +10,8 @@ class LangUtils
 {
 public:
     static bool isLatinAlphabet(const QString& lang);
+    /* Whether accents should be ignored or not. */
+    static bool shouldStripAccents(const QString& lang);
     static bool hasSpecialChars(const QString& lang);
     static QFont fontForLanguage(const QString& lang);
     static QString capitalize(const QString& str, const QString& lang);
